# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlVerkeersbordCode(KeuzelijstField):
    """De code van het verkeersbord volgens de wegcode."""
    naam = 'KlVerkeersbordCode'
    label = 'Verkeersbordcode'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlVerkeersbordCode'
    definition = 'De code van het verkeersbord volgens de wegcode.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlVerkeersbordCode'
    options = {
        'A11': KeuzelijstWaarde(invulwaarde='A11',
                                label='A11',
                                status='ingebruik',
                                definitie='A11',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A11'),
        'A13': KeuzelijstWaarde(invulwaarde='A13',
                                label='A13',
                                status='ingebruik',
                                definitie='A13',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A13'),
        'A14': KeuzelijstWaarde(invulwaarde='A14',
                                label='A14',
                                status='ingebruik',
                                definitie='A14',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A14'),
        'A15': KeuzelijstWaarde(invulwaarde='A15',
                                label='A15',
                                status='ingebruik',
                                definitie='A15',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A15'),
        'A17': KeuzelijstWaarde(invulwaarde='A17',
                                label='A17',
                                status='ingebruik',
                                definitie='A17',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A17'),
        'A19': KeuzelijstWaarde(invulwaarde='A19',
                                label='A19',
                                status='ingebruik',
                                definitie='A19',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A19'),
        'A1a': KeuzelijstWaarde(invulwaarde='A1a',
                                label='A1a',
                                status='ingebruik',
                                definitie='A1a',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A1a'),
        'A1b': KeuzelijstWaarde(invulwaarde='A1b',
                                label='A1b',
                                status='ingebruik',
                                definitie='A1b',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A1b'),
        'A1c': KeuzelijstWaarde(invulwaarde='A1c',
                                label='A1c',
                                status='ingebruik',
                                definitie='A1c',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A1c'),
        'A1d': KeuzelijstWaarde(invulwaarde='A1d',
                                label='A1d',
                                status='ingebruik',
                                definitie='A1d',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A1d'),
        'A21': KeuzelijstWaarde(invulwaarde='A21',
                                label='A21',
                                status='ingebruik',
                                definitie='A21',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A21'),
        'A23': KeuzelijstWaarde(invulwaarde='A23',
                                label='A23',
                                status='ingebruik',
                                definitie='A23',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A23'),
        'A25': KeuzelijstWaarde(invulwaarde='A25',
                                label='A25',
                                status='ingebruik',
                                definitie='A25',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A25'),
        'A27': KeuzelijstWaarde(invulwaarde='A27',
                                label='A27',
                                status='ingebruik',
                                definitie='A27',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A27'),
        'A29': KeuzelijstWaarde(invulwaarde='A29',
                                label='A29',
                                status='ingebruik',
                                definitie='A29',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A29'),
        'A3': KeuzelijstWaarde(invulwaarde='A3',
                               label='A3',
                               status='ingebruik',
                               definitie='A3',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A3'),
        'A31': KeuzelijstWaarde(invulwaarde='A31',
                                label='A31',
                                status='ingebruik',
                                definitie='A31',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A31'),
        'A33': KeuzelijstWaarde(invulwaarde='A33',
                                label='A33',
                                status='ingebruik',
                                definitie='A33',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A33'),
        'A35': KeuzelijstWaarde(invulwaarde='A35',
                                label='A35',
                                status='ingebruik',
                                definitie='A35',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A35'),
        'A37': KeuzelijstWaarde(invulwaarde='A37',
                                label='A37',
                                status='ingebruik',
                                definitie='A37',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A37'),
        'A39': KeuzelijstWaarde(invulwaarde='A39',
                                label='A39',
                                status='ingebruik',
                                definitie='A39',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A39'),
        'A41': KeuzelijstWaarde(invulwaarde='A41',
                                label='A41',
                                status='ingebruik',
                                definitie='A41',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A41'),
        'A43': KeuzelijstWaarde(invulwaarde='A43',
                                label='A43',
                                status='ingebruik',
                                definitie='A43',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A43'),
        'A45': KeuzelijstWaarde(invulwaarde='A45',
                                label='A45',
                                status='ingebruik',
                                definitie='A45',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A45'),
        'A47': KeuzelijstWaarde(invulwaarde='A47',
                                label='A47',
                                status='ingebruik',
                                definitie='A47',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A47'),
        'A49': KeuzelijstWaarde(invulwaarde='A49',
                                label='A49',
                                status='ingebruik',
                                definitie='A49',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A49'),
        'A5': KeuzelijstWaarde(invulwaarde='A5',
                               label='A5',
                               status='ingebruik',
                               definitie='A5',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A5'),
        'A51': KeuzelijstWaarde(invulwaarde='A51',
                                label='A51',
                                status='ingebruik',
                                definitie='A51',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A51'),
        'A7a': KeuzelijstWaarde(invulwaarde='A7a',
                                label='A7a',
                                status='ingebruik',
                                definitie='A7a',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A7a'),
        'A7b': KeuzelijstWaarde(invulwaarde='A7b',
                                label='A7b',
                                status='ingebruik',
                                definitie='A7b',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A7b'),
        'A7c': KeuzelijstWaarde(invulwaarde='A7c',
                                label='A7c',
                                status='ingebruik',
                                definitie='A7c',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A7c'),
        'A9': KeuzelijstWaarde(invulwaarde='A9',
                               label='A9',
                               status='ingebruik',
                               definitie='A9',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/A9'),
        'B1': KeuzelijstWaarde(invulwaarde='B1',
                               label='B1',
                               status='ingebruik',
                               definitie='B1',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B1'),
        'B11': KeuzelijstWaarde(invulwaarde='B11',
                                label='B11',
                                status='ingebruik',
                                definitie='B11',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B11'),
        'B13': KeuzelijstWaarde(invulwaarde='B13',
                                label='B13',
                                status='ingebruik',
                                definitie='B13',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B13'),
        'B15a': KeuzelijstWaarde(invulwaarde='B15a',
                                 label='B15a',
                                 status='ingebruik',
                                 definitie='B15a',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B15a'),
        'B15b': KeuzelijstWaarde(invulwaarde='B15b',
                                 label='B15b',
                                 status='ingebruik',
                                 definitie='B15b',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B15b'),
        'B15c': KeuzelijstWaarde(invulwaarde='B15c',
                                 label='B15c',
                                 status='ingebruik',
                                 definitie='B15c',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B15c'),
        'B15d': KeuzelijstWaarde(invulwaarde='B15d',
                                 label='B15d',
                                 status='ingebruik',
                                 definitie='B15d',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B15d'),
        'B15e': KeuzelijstWaarde(invulwaarde='B15e',
                                 label='B15e',
                                 status='ingebruik',
                                 definitie='B15e',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B15e'),
        'B15f': KeuzelijstWaarde(invulwaarde='B15f',
                                 label='B15f',
                                 status='ingebruik',
                                 definitie='B15f',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B15f'),
        'B15g': KeuzelijstWaarde(invulwaarde='B15g',
                                 label='B15g',
                                 status='ingebruik',
                                 definitie='B15g',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B15g'),
        'B17': KeuzelijstWaarde(invulwaarde='B17',
                                label='B17',
                                status='ingebruik',
                                definitie='B17',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B17'),
        'B19': KeuzelijstWaarde(invulwaarde='B19',
                                label='B19',
                                status='ingebruik',
                                definitie='B19',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B19'),
        'B21': KeuzelijstWaarde(invulwaarde='B21',
                                label='B21',
                                status='ingebruik',
                                definitie='B21',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B21'),
        'B22': KeuzelijstWaarde(invulwaarde='B22',
                                label='B22',
                                status='ingebruik',
                                definitie='B22',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B22'),
        'B23': KeuzelijstWaarde(invulwaarde='B23',
                                label='B23',
                                status='ingebruik',
                                definitie='B23',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B23'),
        'B3': KeuzelijstWaarde(invulwaarde='B3',
                               label='B3',
                               status='ingebruik',
                               definitie='B3',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B3'),
        'B5': KeuzelijstWaarde(invulwaarde='B5',
                               label='B5',
                               status='ingebruik',
                               definitie='B5',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B5'),
        'B7': KeuzelijstWaarde(invulwaarde='B7',
                               label='B7',
                               status='ingebruik',
                               definitie='B7',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B7'),
        'B9': KeuzelijstWaarde(invulwaarde='B9',
                               label='B9',
                               status='ingebruik',
                               definitie='B9',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/B9'),
        'C1': KeuzelijstWaarde(invulwaarde='C1',
                               label='C1',
                               status='ingebruik',
                               definitie='C1',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C1'),
        'C11': KeuzelijstWaarde(invulwaarde='C11',
                                label='C11',
                                status='ingebruik',
                                definitie='C11',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C11'),
        'C13': KeuzelijstWaarde(invulwaarde='C13',
                                label='C13',
                                status='ingebruik',
                                definitie='C13',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C13'),
        'C15': KeuzelijstWaarde(invulwaarde='C15',
                                label='C15',
                                status='ingebruik',
                                definitie='C15',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C15'),
        'C17': KeuzelijstWaarde(invulwaarde='C17',
                                label='C17',
                                status='ingebruik',
                                definitie='C17',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C17'),
        'C19': KeuzelijstWaarde(invulwaarde='C19',
                                label='C19',
                                status='ingebruik',
                                definitie='C19',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C19'),
        'C21': KeuzelijstWaarde(invulwaarde='C21',
                                label='C21',
                                status='ingebruik',
                                definitie='C21',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C21'),
        'C22': KeuzelijstWaarde(invulwaarde='C22',
                                label='C22',
                                status='ingebruik',
                                definitie='C22',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C22'),
        'C23': KeuzelijstWaarde(invulwaarde='C23',
                                label='C23',
                                status='ingebruik',
                                definitie='C23',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C23'),
        'C24a': KeuzelijstWaarde(invulwaarde='C24a',
                                 label='C24a',
                                 status='ingebruik',
                                 definitie='C24a',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C24a'),
        'C24b': KeuzelijstWaarde(invulwaarde='C24b',
                                 label='C24b',
                                 status='ingebruik',
                                 definitie='C24b',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C24b'),
        'C24c': KeuzelijstWaarde(invulwaarde='C24c',
                                 label='C24c',
                                 status='ingebruik',
                                 definitie='C24c',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C24c'),
        'C25': KeuzelijstWaarde(invulwaarde='C25',
                                label='C25',
                                status='ingebruik',
                                definitie='C25',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C25'),
        'C27': KeuzelijstWaarde(invulwaarde='C27',
                                label='C27',
                                status='ingebruik',
                                definitie='C27',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C27'),
        'C29': KeuzelijstWaarde(invulwaarde='C29',
                                label='C29',
                                status='ingebruik',
                                definitie='C29',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C29'),
        'C3': KeuzelijstWaarde(invulwaarde='C3',
                               label='C3',
                               status='ingebruik',
                               definitie='C3',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C3'),
        'C31a': KeuzelijstWaarde(invulwaarde='C31a',
                                 label='C31a',
                                 status='ingebruik',
                                 definitie='C31a',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C31a'),
        'C31b': KeuzelijstWaarde(invulwaarde='C31b',
                                 label='C31b',
                                 status='ingebruik',
                                 definitie='C31b',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C31b'),
        'C33': KeuzelijstWaarde(invulwaarde='C33',
                                label='C33',
                                status='ingebruik',
                                definitie='C33',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C33'),
        'C35': KeuzelijstWaarde(invulwaarde='C35',
                                label='C35',
                                status='ingebruik',
                                definitie='C35',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C35'),
        'C37': KeuzelijstWaarde(invulwaarde='C37',
                                label='C37',
                                status='ingebruik',
                                definitie='C37',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C37'),
        'C39': KeuzelijstWaarde(invulwaarde='C39',
                                label='C39',
                                status='ingebruik',
                                definitie='C39',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C39'),
        'C41': KeuzelijstWaarde(invulwaarde='C41',
                                label='C41',
                                status='ingebruik',
                                definitie='C41',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C41'),
        'C43': KeuzelijstWaarde(invulwaarde='C43',
                                label='C43',
                                status='ingebruik',
                                definitie='C43',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C43'),
        'C45': KeuzelijstWaarde(invulwaarde='C45',
                                label='C45',
                                status='ingebruik',
                                definitie='C45',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C45'),
        'C46': KeuzelijstWaarde(invulwaarde='C46',
                                label='C46',
                                status='ingebruik',
                                definitie='C46',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C46'),
        'C47': KeuzelijstWaarde(invulwaarde='C47',
                                label='C47',
                                status='ingebruik',
                                definitie='C47',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C47'),
        'C5': KeuzelijstWaarde(invulwaarde='C5',
                               label='C5',
                               status='ingebruik',
                               definitie='C5',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C5'),
        'C5-C7': KeuzelijstWaarde(invulwaarde='C5-C7',
                                  label='C5-C7',
                                  status='ingebruik',
                                  definitie='C5-C7',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C5-C7'),
        'C6': KeuzelijstWaarde(invulwaarde='C6',
                               label='C6',
                               status='ingebruik',
                               definitie='C6',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C6'),
        'C7': KeuzelijstWaarde(invulwaarde='C7',
                               label='C7',
                               status='ingebruik',
                               definitie='C7',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C7'),
        'C9': KeuzelijstWaarde(invulwaarde='C9',
                               label='C9',
                               status='ingebruik',
                               definitie='C9',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C9'),
        'C9-C11': KeuzelijstWaarde(invulwaarde='C9-C11',
                                   label='C9-C11',
                                   status='ingebruik',
                                   definitie='C9-C11',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/C9-C11'),
        'D10': KeuzelijstWaarde(invulwaarde='D10',
                                label='D10',
                                status='ingebruik',
                                definitie='D10',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/D10'),
        'D11': KeuzelijstWaarde(invulwaarde='D11',
                                label='D11',
                                status='ingebruik',
                                definitie='D11',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/D11'),
        'D13': KeuzelijstWaarde(invulwaarde='D13',
                                label='D13',
                                status='ingebruik',
                                definitie='D13',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/D13'),
        'D1a': KeuzelijstWaarde(invulwaarde='D1a',
                                label='D1a',
                                status='ingebruik',
                                definitie='D1a',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/D1a'),
        'D1b': KeuzelijstWaarde(invulwaarde='D1b',
                                label='D1b',
                                status='ingebruik',
                                definitie='D1b',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/D1b'),
        'D1c': KeuzelijstWaarde(invulwaarde='D1c',
                                label='D1c',
                                status='ingebruik',
                                definitie='D1c',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/D1c'),
        'D1d': KeuzelijstWaarde(invulwaarde='D1d',
                                label='D1d',
                                status='ingebruik',
                                definitie='D1d',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/D1d'),
        'D1e': KeuzelijstWaarde(invulwaarde='D1e',
                                label='D1e',
                                status='ingebruik',
                                definitie='D1e',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/D1e'),
        'D1f': KeuzelijstWaarde(invulwaarde='D1f',
                                label='D1f',
                                status='ingebruik',
                                definitie='D1f',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/D1f'),
        'D3a': KeuzelijstWaarde(invulwaarde='D3a',
                                label='D3a',
                                status='ingebruik',
                                definitie='D3a',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/D3a'),
        'D3b': KeuzelijstWaarde(invulwaarde='D3b',
                                label='D3b',
                                status='ingebruik',
                                definitie='D3b',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/D3b'),
        'D4': KeuzelijstWaarde(invulwaarde='D4',
                               label='D4',
                               status='ingebruik',
                               definitie='D4',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/D4'),
        'D5': KeuzelijstWaarde(invulwaarde='D5',
                               label='D5',
                               status='ingebruik',
                               definitie='D5',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/D5'),
        'D7': KeuzelijstWaarde(invulwaarde='D7',
                               label='D7',
                               status='ingebruik',
                               definitie='D7',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/D7'),
        'D9a': KeuzelijstWaarde(invulwaarde='D9a',
                                label='D9a',
                                status='ingebruik',
                                definitie='D9a',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/D9a'),
        'D9b': KeuzelijstWaarde(invulwaarde='D9b',
                                label='D9b',
                                status='ingebruik',
                                definitie='D9b',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/D9b'),
        'E1': KeuzelijstWaarde(invulwaarde='E1',
                               label='E1',
                               status='ingebruik',
                               definitie='E1',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/E1'),
        'E11': KeuzelijstWaarde(invulwaarde='E11',
                                label='E11',
                                status='ingebruik',
                                definitie='E11',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/E11'),
        'E3': KeuzelijstWaarde(invulwaarde='E3',
                               label='E3',
                               status='ingebruik',
                               definitie='E3',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/E3'),
        'E5': KeuzelijstWaarde(invulwaarde='E5',
                               label='E5',
                               status='ingebruik',
                               definitie='E5',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/E5'),
        'E7': KeuzelijstWaarde(invulwaarde='E7',
                               label='E7',
                               status='ingebruik',
                               definitie='E7',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/E7'),
        'E9a': KeuzelijstWaarde(invulwaarde='E9a',
                                label='E9a',
                                status='ingebruik',
                                definitie='E9a',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/E9a'),
        'E9b': KeuzelijstWaarde(invulwaarde='E9b',
                                label='E9b',
                                status='ingebruik',
                                definitie='E9b',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/E9b'),
        'E9c': KeuzelijstWaarde(invulwaarde='E9c',
                                label='E9c',
                                status='ingebruik',
                                definitie='E9c',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/E9c'),
        'E9d': KeuzelijstWaarde(invulwaarde='E9d',
                                label='E9d',
                                status='ingebruik',
                                definitie='E9d',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/E9d'),
        'E9e': KeuzelijstWaarde(invulwaarde='E9e',
                                label='E9e',
                                status='ingebruik',
                                definitie='E9e',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/E9e'),
        'E9f': KeuzelijstWaarde(invulwaarde='E9f',
                                label='E9f',
                                status='ingebruik',
                                definitie='E9f',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/E9f'),
        'E9g': KeuzelijstWaarde(invulwaarde='E9g',
                                label='E9g',
                                status='ingebruik',
                                definitie='E9g',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/E9g'),
        'E9h': KeuzelijstWaarde(invulwaarde='E9h',
                                label='E9h',
                                status='ingebruik',
                                definitie='E9h',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/E9h'),
        'E9i': KeuzelijstWaarde(invulwaarde='E9i',
                                label='E9i',
                                status='ingebruik',
                                definitie='E9i',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/E9i'),
        'E9j': KeuzelijstWaarde(invulwaarde='E9j',
                                label='E9j',
                                status='ingebruik',
                                definitie='E9j',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/E9j'),
        'F101a': KeuzelijstWaarde(invulwaarde='F101a',
                                  label='F101a',
                                  status='ingebruik',
                                  definitie='F101a',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F101a'),
        'F101b': KeuzelijstWaarde(invulwaarde='F101b',
                                  label='F101b',
                                  status='ingebruik',
                                  definitie='F101b',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F101b'),
        'F101c': KeuzelijstWaarde(invulwaarde='F101c',
                                  label='F101c',
                                  status='ingebruik',
                                  definitie='F101c',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F101c'),
        'F103': KeuzelijstWaarde(invulwaarde='F103',
                                 label='F103',
                                 status='ingebruik',
                                 definitie='F103',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F103'),
        'F105': KeuzelijstWaarde(invulwaarde='F105',
                                 label='F105',
                                 status='ingebruik',
                                 definitie='F105',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F105'),
        'F11': KeuzelijstWaarde(invulwaarde='F11',
                                label='F11',
                                status='ingebruik',
                                definitie='F11',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F11'),
        'F111': KeuzelijstWaarde(invulwaarde='F111',
                                 label='F111',
                                 status='ingebruik',
                                 definitie='F111',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F111'),
        'F113': KeuzelijstWaarde(invulwaarde='F113',
                                 label='F113',
                                 status='ingebruik',
                                 definitie='F113',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F113'),
        'F119': KeuzelijstWaarde(invulwaarde='F119',
                                 label='F119',
                                 status='ingebruik',
                                 definitie='F119',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F119'),
        'F120': KeuzelijstWaarde(invulwaarde='F120',
                                 label='F120',
                                 status='ingebruik',
                                 definitie='F120',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F120'),
        'F12a': KeuzelijstWaarde(invulwaarde='F12a',
                                 label='F12a',
                                 status='ingebruik',
                                 definitie='F12a',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F12a'),
        'F12b': KeuzelijstWaarde(invulwaarde='F12b',
                                 label='F12b',
                                 status='ingebruik',
                                 definitie='F12b',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F12b'),
        'F13': KeuzelijstWaarde(invulwaarde='F13',
                                label='F13',
                                status='ingebruik',
                                definitie='F13',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F13'),
        'F14': KeuzelijstWaarde(invulwaarde='F14',
                                label='F14',
                                status='ingebruik',
                                definitie='F14',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F14'),
        'F15': KeuzelijstWaarde(invulwaarde='F15',
                                label='F15',
                                status='ingebruik',
                                definitie='F15',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F15'),
        'F17': KeuzelijstWaarde(invulwaarde='F17',
                                label='F17',
                                status='ingebruik',
                                definitie='F17',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F17'),
        'F18': KeuzelijstWaarde(invulwaarde='F18',
                                label='F18',
                                status='ingebruik',
                                definitie='F18',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F18'),
        'F19': KeuzelijstWaarde(invulwaarde='F19',
                                label='F19',
                                status='ingebruik',
                                definitie='F19',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F19'),
        'F1a': KeuzelijstWaarde(invulwaarde='F1a',
                                label='F1a',
                                status='ingebruik',
                                definitie='F1a',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F1a'),
        'F1b': KeuzelijstWaarde(invulwaarde='F1b',
                                label='F1b',
                                status='ingebruik',
                                definitie='F1b',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F1b'),
        'F1b2': KeuzelijstWaarde(invulwaarde='F1b2',
                                 label='F1b2',
                                 status='ingebruik',
                                 definitie='F1b2',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F1b2'),
        'F21': KeuzelijstWaarde(invulwaarde='F21',
                                label='F21',
                                status='ingebruik',
                                definitie='F21',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F21'),
        'F23a': KeuzelijstWaarde(invulwaarde='F23a',
                                 label='F23a',
                                 status='ingebruik',
                                 definitie='F23a',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F23a'),
        'F23b': KeuzelijstWaarde(invulwaarde='F23b',
                                 label='F23b',
                                 status='ingebruik',
                                 definitie='F23b',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F23b'),
        'F23c': KeuzelijstWaarde(invulwaarde='F23c',
                                 label='F23c',
                                 status='ingebruik',
                                 definitie='F23c',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F23c'),
        'F23d': KeuzelijstWaarde(invulwaarde='F23d',
                                 label='F23d',
                                 status='ingebruik',
                                 definitie='F23d',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F23d'),
        'F25': KeuzelijstWaarde(invulwaarde='F25',
                                label='F25',
                                status='ingebruik',
                                definitie='F25',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F25'),
        'F25M': KeuzelijstWaarde(invulwaarde='F25M',
                                 label='F25M',
                                 status='ingebruik',
                                 definitie='F25M',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F25M'),
        'F25R': KeuzelijstWaarde(invulwaarde='F25R',
                                 label='F25R',
                                 status='ingebruik',
                                 definitie='F25R',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F25R'),
        'F25V': KeuzelijstWaarde(invulwaarde='F25V',
                                 label='F25V',
                                 status='ingebruik',
                                 definitie='F25V',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F25V'),
        'F25VM': KeuzelijstWaarde(invulwaarde='F25VM',
                                  label='F25VM',
                                  status='ingebruik',
                                  definitie='F25VM',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F25VM'),
        'F25VR': KeuzelijstWaarde(invulwaarde='F25VR',
                                  label='F25VR',
                                  status='ingebruik',
                                  definitie='F25VR',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F25VR'),
        'F27': KeuzelijstWaarde(invulwaarde='F27',
                                label='F27',
                                status='ingebruik',
                                definitie='F27',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F27'),
        'F27V': KeuzelijstWaarde(invulwaarde='F27V',
                                 label='F27V',
                                 status='ingebruik',
                                 definitie='F27V',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F27V'),
        'F29': KeuzelijstWaarde(invulwaarde='F29',
                                label='F29',
                                status='ingebruik',
                                definitie='F29',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F29'),
        'F31': KeuzelijstWaarde(invulwaarde='F31',
                                label='F31',
                                status='ingebruik',
                                definitie='F31',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F31'),
        'F33a': KeuzelijstWaarde(invulwaarde='F33a',
                                 label='F33a',
                                 status='ingebruik',
                                 definitie='F33a',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F33a'),
        'F33b': KeuzelijstWaarde(invulwaarde='F33b',
                                 label='F33b',
                                 status='ingebruik',
                                 definitie='F33b',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F33b'),
        'F33c': KeuzelijstWaarde(invulwaarde='F33c',
                                 label='F33c',
                                 status='ingebruik',
                                 definitie='F33c',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F33c'),
        'F34a': KeuzelijstWaarde(invulwaarde='F34a',
                                 label='F34a',
                                 status='ingebruik',
                                 definitie='F34a',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F34a'),
        'F34b1': KeuzelijstWaarde(invulwaarde='F34b1',
                                  label='F34b1',
                                  status='ingebruik',
                                  definitie='F34b1',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F34b1'),
        'F34b2': KeuzelijstWaarde(invulwaarde='F34b2',
                                  label='F34b2',
                                  status='ingebruik',
                                  definitie='F34b2',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F34b2'),
        'F34c': KeuzelijstWaarde(invulwaarde='F34c',
                                 label='F34c',
                                 status='ingebruik',
                                 definitie='F34c',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F34c'),
        'F34c1': KeuzelijstWaarde(invulwaarde='F34c1',
                                  label='F34c1',
                                  status='ingebruik',
                                  definitie='F34c1',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F34c1'),
        'F34c2': KeuzelijstWaarde(invulwaarde='F34c2',
                                  label='F34c2',
                                  status='ingebruik',
                                  definitie='F34c2',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F34c2'),
        'F35': KeuzelijstWaarde(invulwaarde='F35',
                                label='F35',
                                status='ingebruik',
                                definitie='F35',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F35'),
        'F37': KeuzelijstWaarde(invulwaarde='F37',
                                label='F37',
                                status='ingebruik',
                                definitie='F37',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F37'),
        'F39': KeuzelijstWaarde(invulwaarde='F39',
                                label='F39',
                                status='ingebruik',
                                definitie='F39',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F39'),
        'F3a': KeuzelijstWaarde(invulwaarde='F3a',
                                label='F3a',
                                status='ingebruik',
                                definitie='F3a',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F3a'),
        'F3b': KeuzelijstWaarde(invulwaarde='F3b',
                                label='F3b',
                                status='ingebruik',
                                definitie='F3b',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F3b'),
        'F3b2': KeuzelijstWaarde(invulwaarde='F3b2',
                                 label='F3b2',
                                 status='ingebruik',
                                 definitie='F3b2',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F3b2'),
        'F41': KeuzelijstWaarde(invulwaarde='F41',
                                label='F41',
                                status='ingebruik',
                                definitie='F41',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F41'),
        'F43': KeuzelijstWaarde(invulwaarde='F43',
                                label='F43',
                                status='ingebruik',
                                definitie='F43',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F43'),
        'F45': KeuzelijstWaarde(invulwaarde='F45',
                                label='F45',
                                status='ingebruik',
                                definitie='F45',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F45'),
        'F45b': KeuzelijstWaarde(invulwaarde='F45b',
                                 label='F45b',
                                 status='ingebruik',
                                 definitie='F45b',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F45b'),
        'F47': KeuzelijstWaarde(invulwaarde='F47',
                                label='F47',
                                status='ingebruik',
                                definitie='F47',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F47'),
        'F49': KeuzelijstWaarde(invulwaarde='F49',
                                label='F49',
                                status='ingebruik',
                                definitie='F49',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F49'),
        'F4a': KeuzelijstWaarde(invulwaarde='F4a',
                                label='F4a',
                                status='ingebruik',
                                definitie='F4a',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F4a'),
        'F4b': KeuzelijstWaarde(invulwaarde='F4b',
                                label='F4b',
                                status='ingebruik',
                                definitie='F4b',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F4b'),
        'F5': KeuzelijstWaarde(invulwaarde='F5',
                               label='F5',
                               status='ingebruik',
                               definitie='F5',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F5'),
        'F50': KeuzelijstWaarde(invulwaarde='F50',
                                label='F50',
                                status='ingebruik',
                                definitie='F50',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F50'),
        'F50bis': KeuzelijstWaarde(invulwaarde='F50bis',
                                   label='F50bis',
                                   status='ingebruik',
                                   definitie='F50bis',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F50bis'),
        'F51a': KeuzelijstWaarde(invulwaarde='F51a',
                                 label='F51a',
                                 status='ingebruik',
                                 definitie='F51a',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F51a'),
        'F51b': KeuzelijstWaarde(invulwaarde='F51b',
                                 label='F51b',
                                 status='ingebruik',
                                 definitie='F51b',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F51b'),
        'F52': KeuzelijstWaarde(invulwaarde='F52',
                                label='F52',
                                status='ingebruik',
                                definitie='F52',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F52'),
        'F52bis': KeuzelijstWaarde(invulwaarde='F52bis',
                                   label='F52bis',
                                   status='ingebruik',
                                   definitie='F52bis',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F52bis'),
        'F53': KeuzelijstWaarde(invulwaarde='F53',
                                label='F53',
                                status='ingebruik',
                                definitie='F53',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F53'),
        'F55': KeuzelijstWaarde(invulwaarde='F55',
                                label='F55',
                                status='ingebruik',
                                definitie='F55',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F55'),
        'F56': KeuzelijstWaarde(invulwaarde='F56',
                                label='F56',
                                status='ingebruik',
                                definitie='F56',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F56'),
        'F57': KeuzelijstWaarde(invulwaarde='F57',
                                label='F57',
                                status='ingebruik',
                                definitie='F57',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F57'),
        'F59': KeuzelijstWaarde(invulwaarde='F59',
                                label='F59',
                                status='ingebruik',
                                definitie='F59',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F59'),
        'F59a': KeuzelijstWaarde(invulwaarde='F59a',
                                 label='F59a',
                                 status='ingebruik',
                                 definitie='F59a',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F59a'),
        'F59b': KeuzelijstWaarde(invulwaarde='F59b',
                                 label='F59b',
                                 status='ingebruik',
                                 definitie='F59b',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F59b'),
        'F60': KeuzelijstWaarde(invulwaarde='F60',
                                label='F60',
                                status='ingebruik',
                                definitie='F60',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F60'),
        'F61': KeuzelijstWaarde(invulwaarde='F61',
                                label='F61',
                                status='ingebruik',
                                definitie='F61',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F61'),
        'F63': KeuzelijstWaarde(invulwaarde='F63',
                                label='F63',
                                status='ingebruik',
                                definitie='F63',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F63'),
        'F65': KeuzelijstWaarde(invulwaarde='F65',
                                label='F65',
                                status='ingebruik',
                                definitie='F65',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F65'),
        'F67': KeuzelijstWaarde(invulwaarde='F67',
                                label='F67',
                                status='ingebruik',
                                definitie='F67',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F67'),
        'F69': KeuzelijstWaarde(invulwaarde='F69',
                                label='F69',
                                status='ingebruik',
                                definitie='F69',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F69'),
        'F7': KeuzelijstWaarde(invulwaarde='F7',
                               label='F7',
                               status='ingebruik',
                               definitie='F7',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F7'),
        'F71': KeuzelijstWaarde(invulwaarde='F71',
                                label='F71',
                                status='ingebruik',
                                definitie='F71',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F71'),
        'F73': KeuzelijstWaarde(invulwaarde='F73',
                                label='F73',
                                status='ingebruik',
                                definitie='F73',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F73'),
        'F75': KeuzelijstWaarde(invulwaarde='F75',
                                label='F75',
                                status='ingebruik',
                                definitie='F75',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F75'),
        'F77': KeuzelijstWaarde(invulwaarde='F77',
                                label='F77',
                                status='ingebruik',
                                definitie='F77',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F77'),
        'F79': KeuzelijstWaarde(invulwaarde='F79',
                                label='F79',
                                status='ingebruik',
                                definitie='F79',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F79'),
        'F8': KeuzelijstWaarde(invulwaarde='F8',
                               label='F8',
                               status='ingebruik',
                               definitie='F8',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F8'),
        'F81': KeuzelijstWaarde(invulwaarde='F81',
                                label='F81',
                                status='ingebruik',
                                definitie='F81',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F81'),
        'F83': KeuzelijstWaarde(invulwaarde='F83',
                                label='F83',
                                status='ingebruik',
                                definitie='F83',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F83'),
        'F85': KeuzelijstWaarde(invulwaarde='F85',
                                label='F85',
                                status='ingebruik',
                                definitie='F85',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F85'),
        'F87': KeuzelijstWaarde(invulwaarde='F87',
                                label='F87',
                                status='ingebruik',
                                definitie='F87',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F87'),
        'F89': KeuzelijstWaarde(invulwaarde='F89',
                                label='F89',
                                status='ingebruik',
                                definitie='F89',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F89'),
        'F9': KeuzelijstWaarde(invulwaarde='F9',
                               label='F9',
                               status='ingebruik',
                               definitie='F9',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F9'),
        'F91': KeuzelijstWaarde(invulwaarde='F91',
                                label='F91',
                                status='ingebruik',
                                definitie='F91',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F91'),
        'F93': KeuzelijstWaarde(invulwaarde='F93',
                                label='F93',
                                status='ingebruik',
                                definitie='F93',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F93'),
        'F95': KeuzelijstWaarde(invulwaarde='F95',
                                label='F95',
                                status='ingebruik',
                                definitie='F95',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F95'),
        'F97': KeuzelijstWaarde(invulwaarde='F97',
                                label='F97',
                                status='ingebruik',
                                definitie='F97',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F97'),
        'F98': KeuzelijstWaarde(invulwaarde='F98',
                                label='F98',
                                status='ingebruik',
                                definitie='F98',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F98'),
        'F99a': KeuzelijstWaarde(invulwaarde='F99a',
                                 label='F99a',
                                 status='ingebruik',
                                 definitie='F99a',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F99a'),
        'F99b': KeuzelijstWaarde(invulwaarde='F99b',
                                 label='F99b',
                                 status='ingebruik',
                                 definitie='F99b',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F99b'),
        'F99c': KeuzelijstWaarde(invulwaarde='F99c',
                                 label='F99c',
                                 status='ingebruik',
                                 definitie='F99c',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/F99c'),
        'GF98': KeuzelijstWaarde(invulwaarde='GF98',
                                 label='GF98',
                                 status='ingebruik',
                                 definitie='GF98',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GF98'),
        'GII': KeuzelijstWaarde(invulwaarde='GII',
                                label='GII',
                                status='ingebruik',
                                definitie='GII',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GII'),
        'GIII': KeuzelijstWaarde(invulwaarde='GIII',
                                 label='GIII',
                                 status='ingebruik',
                                 definitie='GIII',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GIII'),
        'GIV': KeuzelijstWaarde(invulwaarde='GIV',
                                label='GIV',
                                status='ingebruik',
                                definitie='GIV',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GIV'),
        'GIX': KeuzelijstWaarde(invulwaarde='GIX',
                                label='GIX',
                                status='ingebruik',
                                definitie='GIX',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GIX'),
        'GIa': KeuzelijstWaarde(invulwaarde='GIa',
                                label='GIa',
                                status='ingebruik',
                                definitie='GIa',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GIa'),
        'GIb': KeuzelijstWaarde(invulwaarde='GIb',
                                label='GIb',
                                status='ingebruik',
                                definitie='GIb',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GIb'),
        'GV': KeuzelijstWaarde(invulwaarde='GV',
                               label='GV',
                               status='ingebruik',
                               definitie='GV',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GV'),
        'GVI': KeuzelijstWaarde(invulwaarde='GVI',
                                label='GVI',
                                status='ingebruik',
                                definitie='GVI',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GVI'),
        'GVIII': KeuzelijstWaarde(invulwaarde='GVIII',
                                  label='GVIII',
                                  status='ingebruik',
                                  definitie='GVIII',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GVIII'),
        'GVIIa': KeuzelijstWaarde(invulwaarde='GVIIa',
                                  label='GVIIa',
                                  status='ingebruik',
                                  definitie='GVIIa',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GVIIa'),
        'GVIIb': KeuzelijstWaarde(invulwaarde='GVIIb',
                                  label='GVIIb',
                                  status='ingebruik',
                                  definitie='GVIIb',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GVIIb'),
        'GVIIc': KeuzelijstWaarde(invulwaarde='GVIIc',
                                  label='GVIIc',
                                  status='ingebruik',
                                  definitie='GVIIc',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GVIIc'),
        'GVIId': KeuzelijstWaarde(invulwaarde='GVIId',
                                  label='GVIId',
                                  status='ingebruik',
                                  definitie='GVIId',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GVIId'),
        'GXI': KeuzelijstWaarde(invulwaarde='GXI',
                                label='GXI',
                                status='ingebruik',
                                definitie='GXI',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GXI'),
        'GXII': KeuzelijstWaarde(invulwaarde='GXII',
                                 label='GXII',
                                 status='ingebruik',
                                 definitie='GXII',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GXII'),
        'GXa': KeuzelijstWaarde(invulwaarde='GXa',
                                label='GXa',
                                status='ingebruik',
                                definitie='GXa',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GXa'),
        'GXb': KeuzelijstWaarde(invulwaarde='GXb',
                                label='GXb',
                                status='ingebruik',
                                definitie='GXb',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GXb'),
        'GXc': KeuzelijstWaarde(invulwaarde='GXc',
                                label='GXc',
                                status='ingebruik',
                                definitie='GXc',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GXc'),
        'GXd': KeuzelijstWaarde(invulwaarde='GXd',
                                label='GXd',
                                status='ingebruik',
                                definitie='GXd',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/GXd'),
        'M1': KeuzelijstWaarde(invulwaarde='M1',
                               label='M1',
                               status='ingebruik',
                               definitie='M1',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M1'),
        'M10': KeuzelijstWaarde(invulwaarde='M10',
                                label='M10',
                                status='ingebruik',
                                definitie='M10',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M10'),
        'M11': KeuzelijstWaarde(invulwaarde='M11',
                                label='M11',
                                status='ingebruik',
                                definitie='M11',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M11'),
        'M12': KeuzelijstWaarde(invulwaarde='M12',
                                label='M12',
                                status='ingebruik',
                                definitie='M12',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M12'),
        'M13': KeuzelijstWaarde(invulwaarde='M13',
                                label='M13',
                                status='ingebruik',
                                definitie='M13',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M13'),
        'M14': KeuzelijstWaarde(invulwaarde='M14',
                                label='M14',
                                status='ingebruik',
                                definitie='M14',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M14'),
        'M15': KeuzelijstWaarde(invulwaarde='M15',
                                label='M15',
                                status='ingebruik',
                                definitie='M15',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M15'),
        'M16': KeuzelijstWaarde(invulwaarde='M16',
                                label='M16',
                                status='ingebruik',
                                definitie='M16',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M16'),
        'M17': KeuzelijstWaarde(invulwaarde='M17',
                                label='M17',
                                status='ingebruik',
                                definitie='M17',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M17'),
        'M18': KeuzelijstWaarde(invulwaarde='M18',
                                label='M18',
                                status='ingebruik',
                                definitie='M18',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M18'),
        'M19': KeuzelijstWaarde(invulwaarde='M19',
                                label='M19',
                                status='ingebruik',
                                definitie='M19',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M19'),
        'M2': KeuzelijstWaarde(invulwaarde='M2',
                               label='M2',
                               status='ingebruik',
                               definitie='M2',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M2'),
        'M20': KeuzelijstWaarde(invulwaarde='M20',
                                label='M20',
                                status='ingebruik',
                                definitie='M20',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M20'),
        'M21': KeuzelijstWaarde(invulwaarde='M21',
                                label='M21',
                                status='ingebruik',
                                definitie='M21',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M21'),
        'M22': KeuzelijstWaarde(invulwaarde='M22',
                                label='M22',
                                status='ingebruik',
                                definitie='M22',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M22'),
        'M23': KeuzelijstWaarde(invulwaarde='M23',
                                label='M23',
                                status='ingebruik',
                                definitie='M23',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M23'),
        'M241': KeuzelijstWaarde(invulwaarde='M241',
                                 label='M241',
                                 status='ingebruik',
                                 definitie='M241',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M241'),
        'M3': KeuzelijstWaarde(invulwaarde='M3',
                               label='M3',
                               status='ingebruik',
                               definitie='M3',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M3'),
        'M3bis': KeuzelijstWaarde(invulwaarde='M3bis',
                                  label='M3bis',
                                  status='ingebruik',
                                  definitie='M3bis',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M3bis'),
        'M4': KeuzelijstWaarde(invulwaarde='M4',
                               label='M4',
                               status='ingebruik',
                               definitie='M4',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M4'),
        'M5': KeuzelijstWaarde(invulwaarde='M5',
                               label='M5',
                               status='ingebruik',
                               definitie='M5',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M5'),
        'M5bis': KeuzelijstWaarde(invulwaarde='M5bis',
                                  label='M5bis',
                                  status='ingebruik',
                                  definitie='M5bis',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M5bis'),
        'M6': KeuzelijstWaarde(invulwaarde='M6',
                               label='M6',
                               status='ingebruik',
                               definitie='M6',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M6'),
        'M7': KeuzelijstWaarde(invulwaarde='M7',
                               label='M7',
                               status='ingebruik',
                               definitie='M7',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M7'),
        'M8': KeuzelijstWaarde(invulwaarde='M8',
                               label='M8',
                               status='ingebruik',
                               definitie='M8',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M8'),
        'M9': KeuzelijstWaarde(invulwaarde='M9',
                               label='M9',
                               status='ingebruik',
                               definitie='M9',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVerkeersbordCode/M9')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

