# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlProfielhoogtemaat(KeuzelijstField):
    """Voorgedefinieerde hoogtemaat van een profiel."""
    naam = 'KlProfielhoogtemaat'
    label = 'Profielhoogtemaat'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlProfielhoogtemaat'
    definition = 'Voorgedefinieerde hoogtemaat van een profiel.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlProfielhoogtemaat'
    options = {
        '100': KeuzelijstWaarde(invulwaarde='100',
                                label='100',
                                status='ingebruik',
                                definitie='100',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/100'),
        '1000': KeuzelijstWaarde(invulwaarde='1000',
                                 label='1000',
                                 status='ingebruik',
                                 definitie='1000',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/1000'),
        '120': KeuzelijstWaarde(invulwaarde='120',
                                label='120',
                                status='ingebruik',
                                definitie='120',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/120'),
        '140': KeuzelijstWaarde(invulwaarde='140',
                                label='140',
                                status='ingebruik',
                                definitie='140',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/140'),
        '160': KeuzelijstWaarde(invulwaarde='160',
                                label='160',
                                status='ingebruik',
                                definitie='160',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/160'),
        '180': KeuzelijstWaarde(invulwaarde='180',
                                label='180',
                                status='ingebruik',
                                definitie='180',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/180'),
        '200': KeuzelijstWaarde(invulwaarde='200',
                                label='200',
                                status='ingebruik',
                                definitie='200',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/200'),
        '220': KeuzelijstWaarde(invulwaarde='220',
                                label='220',
                                status='ingebruik',
                                definitie='220',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/220'),
        '240': KeuzelijstWaarde(invulwaarde='240',
                                label='240',
                                status='ingebruik',
                                definitie='240',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/240'),
        '260': KeuzelijstWaarde(invulwaarde='260',
                                label='260',
                                status='ingebruik',
                                definitie='260',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/260'),
        '270': KeuzelijstWaarde(invulwaarde='270',
                                label='270',
                                status='ingebruik',
                                definitie='270',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/270'),
        '280': KeuzelijstWaarde(invulwaarde='280',
                                label='280',
                                status='ingebruik',
                                definitie='280',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/280'),
        '300': KeuzelijstWaarde(invulwaarde='300',
                                label='300',
                                status='ingebruik',
                                definitie='300',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/300'),
        '320': KeuzelijstWaarde(invulwaarde='320',
                                label='320',
                                status='ingebruik',
                                definitie='320',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/320'),
        '330': KeuzelijstWaarde(invulwaarde='330',
                                label='330',
                                status='ingebruik',
                                definitie='330',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/330'),
        '340': KeuzelijstWaarde(invulwaarde='340',
                                label='340',
                                status='ingebruik',
                                definitie='340',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/340'),
        '350': KeuzelijstWaarde(invulwaarde='350',
                                label='350',
                                status='ingebruik',
                                definitie='350',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/350'),
        '360': KeuzelijstWaarde(invulwaarde='360',
                                label='360',
                                status='ingebruik',
                                definitie='360',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/360'),
        '380': KeuzelijstWaarde(invulwaarde='380',
                                label='380',
                                status='ingebruik',
                                definitie='380',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/380'),
        '400': KeuzelijstWaarde(invulwaarde='400',
                                label='400',
                                status='ingebruik',
                                definitie='400',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/400'),
        '450': KeuzelijstWaarde(invulwaarde='450',
                                label='450',
                                status='ingebruik',
                                definitie='450',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/450'),
        '500': KeuzelijstWaarde(invulwaarde='500',
                                label='500',
                                status='ingebruik',
                                definitie='500',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/500'),
        '550': KeuzelijstWaarde(invulwaarde='550',
                                label='550',
                                status='ingebruik',
                                definitie='550',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/550'),
        '600': KeuzelijstWaarde(invulwaarde='600',
                                label='600',
                                status='ingebruik',
                                definitie='600',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/600'),
        '650': KeuzelijstWaarde(invulwaarde='650',
                                label='650',
                                status='ingebruik',
                                definitie='650',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/650'),
        '700': KeuzelijstWaarde(invulwaarde='700',
                                label='700',
                                status='ingebruik',
                                definitie='700',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/700'),
        '80': KeuzelijstWaarde(invulwaarde='80',
                               label='80',
                               status='ingebruik',
                               definitie='80',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/80'),
        '800': KeuzelijstWaarde(invulwaarde='800',
                                label='800',
                                status='ingebruik',
                                definitie='800',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/800'),
        '900': KeuzelijstWaarde(invulwaarde='900',
                                label='900',
                                status='ingebruik',
                                definitie='900',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlProfielhoogtemaat/900')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

