# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLumenOutput(KeuzelijstField):
    """Mogelijke waarden uitgedrukt in Lumens."""
    naam = 'KlLumenOutput'
    label = 'Lumen output'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLumenOutput'
    definition = 'Mogelijke waarden uitgedrukt in Lumens.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLumenOutput'
    options = {
        '1000': KeuzelijstWaarde(invulwaarde='1000',
                                 label='1000',
                                 status='ingebruik',
                                 definitie='1000',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/1000'),
        '10000': KeuzelijstWaarde(invulwaarde='10000',
                                  label='10000',
                                  status='ingebruik',
                                  definitie='10000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/10000'),
        '1250': KeuzelijstWaarde(invulwaarde='1250',
                                 label='1250',
                                 status='ingebruik',
                                 definitie='1250',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/1250'),
        '12500': KeuzelijstWaarde(invulwaarde='12500',
                                  label='12500',
                                  status='ingebruik',
                                  definitie='12500',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/12500'),
        '1500': KeuzelijstWaarde(invulwaarde='1500',
                                 label='1500',
                                 status='ingebruik',
                                 definitie='1500',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/1500'),
        '15000': KeuzelijstWaarde(invulwaarde='15000',
                                  label='15000',
                                  status='ingebruik',
                                  definitie='15000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/15000'),
        '1750': KeuzelijstWaarde(invulwaarde='1750',
                                 label='1750',
                                 status='ingebruik',
                                 definitie='1750',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/1750'),
        '17500': KeuzelijstWaarde(invulwaarde='17500',
                                  label='17500',
                                  status='ingebruik',
                                  definitie='17500',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/17500'),
        '2000': KeuzelijstWaarde(invulwaarde='2000',
                                 label='2000',
                                 status='ingebruik',
                                 definitie='2000',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/2000'),
        '20000': KeuzelijstWaarde(invulwaarde='20000',
                                  label='20000',
                                  status='ingebruik',
                                  definitie='20000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/20000'),
        '22500': KeuzelijstWaarde(invulwaarde='22500',
                                  label='22500',
                                  status='ingebruik',
                                  definitie='22500',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/22500'),
        '2500': KeuzelijstWaarde(invulwaarde='2500',
                                 label='2500',
                                 status='ingebruik',
                                 definitie='2500',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/2500'),
        '25000': KeuzelijstWaarde(invulwaarde='25000',
                                  label='25000',
                                  status='ingebruik',
                                  definitie='25000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/25000'),
        '3000': KeuzelijstWaarde(invulwaarde='3000',
                                 label='3000',
                                 status='ingebruik',
                                 definitie='3000',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/3000'),
        '30000': KeuzelijstWaarde(invulwaarde='30000',
                                  label='30000',
                                  status='ingebruik',
                                  definitie='30000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/30000'),
        '3500': KeuzelijstWaarde(invulwaarde='3500',
                                 label='3500',
                                 status='ingebruik',
                                 definitie='3500',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/3500'),
        '35000': KeuzelijstWaarde(invulwaarde='35000',
                                  label='35000',
                                  status='ingebruik',
                                  definitie='35000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/35000'),
        '4000': KeuzelijstWaarde(invulwaarde='4000',
                                 label='4000',
                                 status='ingebruik',
                                 definitie='4000',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/4000'),
        '40000': KeuzelijstWaarde(invulwaarde='40000',
                                  label='40000',
                                  status='ingebruik',
                                  definitie='40000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/40000'),
        '45000': KeuzelijstWaarde(invulwaarde='45000',
                                  label='45000',
                                  status='ingebruik',
                                  definitie='45000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/45000'),
        '5000': KeuzelijstWaarde(invulwaarde='5000',
                                 label='5000',
                                 status='ingebruik',
                                 definitie='5000',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/5000'),
        '50000': KeuzelijstWaarde(invulwaarde='50000',
                                  label='50000',
                                  status='ingebruik',
                                  definitie='50000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/50000'),
        '55000': KeuzelijstWaarde(invulwaarde='55000',
                                  label='55000',
                                  status='ingebruik',
                                  definitie='55000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/55000'),
        '60000': KeuzelijstWaarde(invulwaarde='60000',
                                  label='60000',
                                  status='ingebruik',
                                  definitie='60000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/60000'),
        '6250': KeuzelijstWaarde(invulwaarde='6250',
                                 label='6250',
                                 status='ingebruik',
                                 definitie='6250',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/6250'),
        '70000': KeuzelijstWaarde(invulwaarde='70000',
                                  label='70000',
                                  status='ingebruik',
                                  definitie='70000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/70000'),
        '7500': KeuzelijstWaarde(invulwaarde='7500',
                                 label='7500',
                                 status='ingebruik',
                                 definitie='7500',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/7500'),
        '8750': KeuzelijstWaarde(invulwaarde='8750',
                                 label='8750',
                                 status='ingebruik',
                                 definitie='8750',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/8750')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

