# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlVoedingskabelAdersEnSectie(KeuzelijstField):
    """Lijst van mogelijke waarden volgens de catalogusposten van het standaardbestek voor de samenstelling van een voedingskabel volgens het aantal aders en hun dikte in vierkante millimeter."""
    naam = 'KlVoedingskabelAdersEnSectie'
    label = 'Voedingskabel aders en sectie'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlVoedingskabelAdersEnSectie'
    definition = 'Lijst van mogelijke waarden volgens de catalogusposten van het standaardbestek voor de samenstelling van een voedingskabel volgens het aantal aders en hun dikte in vierkante millimeter.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlVoedingskabelAdersEnSectie'
    options = {
        '1-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='1-x-1.5-mm2',
                                        label='1 x 1.5 mm²',
                                        status='uitgebruik',
                                        definitie='uitgebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/1-x-1.5-mm2'),
        '1-x-10-mm2': KeuzelijstWaarde(invulwaarde='1-x-10-mm2',
                                       label='1 x 10 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/1-x-10-mm2'),
        '1-x-16-mm2': KeuzelijstWaarde(invulwaarde='1-x-16-mm2',
                                       label='1 x 16 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/1-x-16-mm2'),
        '1-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='1-x-2.5-mm2',
                                        label='1 x 2.5 mm²',
                                        status='uitgebruik',
                                        definitie='uitgebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/1-x-2.5-mm2'),
        '1-x-25-mm2': KeuzelijstWaarde(invulwaarde='1-x-25-mm2',
                                       label='1 x 25 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/1-x-25-mm2'),
        '1-x-4-mm2': KeuzelijstWaarde(invulwaarde='1-x-4-mm2',
                                      label='1 x 4 mm²',
                                      status='uitgebruik',
                                      definitie='uitgebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/1-x-4-mm2'),
        '1-x-6-mm2': KeuzelijstWaarde(invulwaarde='1-x-6-mm2',
                                      label='1 x 6 mm²',
                                      status='uitgebruik',
                                      definitie='uitgebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/1-x-6-mm2'),
        '1.5': KeuzelijstWaarde(invulwaarde='1.5',
                                label='1.5',
                                status='ingebruik',
                                definitie='1.5',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/1.5'),
        '16': KeuzelijstWaarde(invulwaarde='16',
                               label='16',
                               status='ingebruik',
                               definitie='16',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/16'),
        '19x1.5': KeuzelijstWaarde(invulwaarde='19x1.5',
                                   label='19x1.5',
                                   status='ingebruik',
                                   definitie='19x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/19x1.5'),
        '1x2.5': KeuzelijstWaarde(invulwaarde='1x2.5',
                                  label='1x2.5',
                                  status='ingebruik',
                                  definitie='1x2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/1x2.5'),
        '25': KeuzelijstWaarde(invulwaarde='25',
                               label='25',
                               status='ingebruik',
                               definitie='25',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/25'),
        '27x1.5': KeuzelijstWaarde(invulwaarde='27x1.5',
                                   label='27x1.5',
                                   status='ingebruik',
                                   definitie='27x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/27x1.5'),
        '2x1.5': KeuzelijstWaarde(invulwaarde='2x1.5',
                                  label='2x1.5',
                                  status='ingebruik',
                                  definitie='2x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/2x1.5'),
        '2x2.5': KeuzelijstWaarde(invulwaarde='2x2.5',
                                  label='2x2.5',
                                  status='ingebruik',
                                  definitie='2x2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/2x2.5'),
        '2x2.5-2.5': KeuzelijstWaarde(invulwaarde='2x2.5-2.5',
                                      label='2x2.5+2.5',
                                      status='ingebruik',
                                      definitie='2x2.5+2.5',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/2x2.5-2.5'),
        '2x25-16': KeuzelijstWaarde(invulwaarde='2x25-16',
                                    label='2x25+16',
                                    status='ingebruik',
                                    definitie='2x25+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/2x25-16'),
        '2x4': KeuzelijstWaarde(invulwaarde='2x4',
                                label='2x4',
                                status='ingebruik',
                                definitie='2x4',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/2x4'),
        '3-x-10-6-mm2': KeuzelijstWaarde(invulwaarde='3-x-10-6-mm2',
                                         label='3 x 10+6 mm²',
                                         status='uitgebruik',
                                         definitie='uitgebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3-x-10-6-mm2'),
        '3-x-16-10-mm2': KeuzelijstWaarde(invulwaarde='3-x-16-10-mm2',
                                          label='3 x 16+10 mm²',
                                          status='uitgebruik',
                                          definitie='uitgebruik',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3-x-16-10-mm2'),
        '3-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='3-x-2.5-mm2',
                                        label='3 x 2.5 mm²',
                                        status='uitgebruik',
                                        definitie='uitgebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3-x-2.5-mm2'),
        '3-x-25---1-x-16-mm2': KeuzelijstWaarde(invulwaarde='3-x-25---1-x-16-mm2',
                                                label='3 x 25 + 1 x 16 mm²',
                                                status='uitgebruik',
                                                definitie='uitgebruik',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3-x-25---1-x-16-mm2'),
        '3-x-25-16-mm2': KeuzelijstWaarde(invulwaarde='3-x-25-16-mm2',
                                          label='3 x 25+16 mm²',
                                          status='uitgebruik',
                                          definitie='uitgebruik',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3-x-25-16-mm2'),
        '3-x-35-25-mm2': KeuzelijstWaarde(invulwaarde='3-x-35-25-mm2',
                                          label='3 x 35+25 mm²',
                                          status='uitgebruik',
                                          definitie='uitgebruik',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3-x-35-25-mm2'),
        '30x1.5': KeuzelijstWaarde(invulwaarde='30x1.5',
                                   label='30x1.5',
                                   status='ingebruik',
                                   definitie='30x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/30x1.5'),
        '37x1.5': KeuzelijstWaarde(invulwaarde='37x1.5',
                                   label='37x1.5',
                                   status='ingebruik',
                                   definitie='37x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/37x1.5'),
        '3g1.5': KeuzelijstWaarde(invulwaarde='3g1.5',
                                  label='3G1.5',
                                  status='ingebruik',
                                  definitie='3G1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3g1.5'),
        '3g10': KeuzelijstWaarde(invulwaarde='3g10',
                                 label='3G10',
                                 status='ingebruik',
                                 definitie='3G10',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3g10'),
        '3g2': KeuzelijstWaarde(invulwaarde='3g2',
                                label='3G2',
                                status='ingebruik',
                                definitie='3G2',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3g2'),
        '3g2.5': KeuzelijstWaarde(invulwaarde='3g2.5',
                                  label='3G2.5',
                                  status='ingebruik',
                                  definitie='3G2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3g2.5'),
        '3g2.5-mm2': KeuzelijstWaarde(invulwaarde='3g2.5-mm2',
                                      label='3G2.5 mm²',
                                      status='uitgebruik',
                                      definitie='uitgebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3g2.5-mm2'),
        '3g2x5': KeuzelijstWaarde(invulwaarde='3g2x5',
                                  label='3G2x5',
                                  status='ingebruik',
                                  definitie='3G2x5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3g2x5'),
        '3g4': KeuzelijstWaarde(invulwaarde='3g4',
                                label='3G4',
                                status='ingebruik',
                                definitie='3G4',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3g4'),
        '3x1.5': KeuzelijstWaarde(invulwaarde='3x1.5',
                                  label='3x1.5',
                                  status='ingebruik',
                                  definitie='3x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x1.5'),
        '3x10-10': KeuzelijstWaarde(invulwaarde='3x10-10',
                                    label='3x10+10',
                                    status='ingebruik',
                                    definitie='3x10+10',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x10-10'),
        '3x10-16': KeuzelijstWaarde(invulwaarde='3x10-16',
                                    label='3x10+16',
                                    status='ingebruik',
                                    definitie='3x10+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x10-16'),
        '3x10-6': KeuzelijstWaarde(invulwaarde='3x10-6',
                                   label='3x10+6',
                                   status='ingebruik',
                                   definitie='3x10+6',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x10-6'),
        '3x16-10': KeuzelijstWaarde(invulwaarde='3x16-10',
                                    label='3x16+10',
                                    status='ingebruik',
                                    definitie='3x16+10',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x16-10'),
        '3x16-16': KeuzelijstWaarde(invulwaarde='3x16-16',
                                    label='3x16+16',
                                    status='ingebruik',
                                    definitie='3x16+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x16-16'),
        '3x2.5': KeuzelijstWaarde(invulwaarde='3x2.5',
                                  label='3x2.5',
                                  status='ingebruik',
                                  definitie='3x2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x2.5'),
        '3x2.5-16': KeuzelijstWaarde(invulwaarde='3x2.5-16',
                                     label='3x2.5+16',
                                     status='ingebruik',
                                     definitie='3x2.5+16',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x2.5-16'),
        '3x25': KeuzelijstWaarde(invulwaarde='3x25',
                                 label='3x25',
                                 status='ingebruik',
                                 definitie='3x25',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x25'),
        '3x25-10': KeuzelijstWaarde(invulwaarde='3x25-10',
                                    label='3x25+10',
                                    status='ingebruik',
                                    definitie='3x25+10',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x25-10'),
        '3x25-15': KeuzelijstWaarde(invulwaarde='3x25-15',
                                    label='3x25+15',
                                    status='ingebruik',
                                    definitie='3x25+15',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x25-15'),
        '3x25-16': KeuzelijstWaarde(invulwaarde='3x25-16',
                                    label='3x25+16',
                                    status='ingebruik',
                                    definitie='3x25+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x25-16'),
        '3x25-25': KeuzelijstWaarde(invulwaarde='3x25-25',
                                    label='3x25+25',
                                    status='ingebruik',
                                    definitie='3x25+25',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x25-25'),
        '3x25-6': KeuzelijstWaarde(invulwaarde='3x25-6',
                                   label='3x25+6',
                                   status='ingebruik',
                                   definitie='3x25+6',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x25-6'),
        '3x35-16': KeuzelijstWaarde(invulwaarde='3x35-16',
                                    label='3x35+16',
                                    status='ingebruik',
                                    definitie='3x35+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x35-16'),
        '3x35-25': KeuzelijstWaarde(invulwaarde='3x35-25',
                                    label='3x35+25',
                                    status='ingebruik',
                                    definitie='3x35+25',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x35-25'),
        '3x50-25': KeuzelijstWaarde(invulwaarde='3x50-25',
                                    label='3x50+25',
                                    status='ingebruik',
                                    definitie='3x50+25',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x50-25'),
        '3x95-50': KeuzelijstWaarde(invulwaarde='3x95-50',
                                    label='3x95+50',
                                    status='ingebruik',
                                    definitie='3x95+50',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/3x95-50'),
        '4-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='4-x-1.5-mm2',
                                        label='4 x 1.5 mm²',
                                        status='uitgebruik',
                                        definitie='uitgebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-1.5-mm2'),
        '4-x-10-mm2': KeuzelijstWaarde(invulwaarde='4-x-10-mm2',
                                       label='4 x 10 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-10-mm2'),
        '4-x-150-mm2': KeuzelijstWaarde(invulwaarde='4-x-150-mm2',
                                        label='4 x 150 mm²',
                                        status='uitgebruik',
                                        definitie='uitgebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-150-mm2'),
        '4-x-16-mm2': KeuzelijstWaarde(invulwaarde='4-x-16-mm2',
                                       label='4 x 16 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-16-mm2'),
        '4-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='4-x-2.5-mm2',
                                        label='4 x 2.5 mm²',
                                        status='uitgebruik',
                                        definitie='uitgebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-2.5-mm2'),
        '4-x-25-mm2': KeuzelijstWaarde(invulwaarde='4-x-25-mm2',
                                       label='4 x 25 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-25-mm2'),
        '4-x-35-mm2': KeuzelijstWaarde(invulwaarde='4-x-35-mm2',
                                       label='4 x 35 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-35-mm2'),
        '4-x-4-mm2': KeuzelijstWaarde(invulwaarde='4-x-4-mm2',
                                      label='4 x 4 mm²',
                                      status='uitgebruik',
                                      definitie='uitgebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-4-mm2'),
        '4-x-50-mm2': KeuzelijstWaarde(invulwaarde='4-x-50-mm2',
                                       label='4 x 50 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-50-mm2'),
        '4-x-6-mm2': KeuzelijstWaarde(invulwaarde='4-x-6-mm2',
                                      label='4 x 6 mm²',
                                      status='uitgebruik',
                                      definitie='uitgebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-6-mm2'),
        '4-x-95-mm2': KeuzelijstWaarde(invulwaarde='4-x-95-mm2',
                                       label='4 x 95 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4-x-95-mm2'),
        '48x1.5': KeuzelijstWaarde(invulwaarde='48x1.5',
                                   label='48x1.5',
                                   status='ingebruik',
                                   definitie='48x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/48x1.5'),
        '49x1.5': KeuzelijstWaarde(invulwaarde='49x1.5',
                                   label='49x1.5',
                                   status='ingebruik',
                                   definitie='49x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/49x1.5'),
        '4g10': KeuzelijstWaarde(invulwaarde='4g10',
                                 label='4G10',
                                 status='ingebruik',
                                 definitie='4G10',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4g10'),
        '4g16': KeuzelijstWaarde(invulwaarde='4g16',
                                 label='4G16',
                                 status='ingebruik',
                                 definitie='4G16',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4g16'),
        '4g2.5': KeuzelijstWaarde(invulwaarde='4g2.5',
                                  label='4G2.5',
                                  status='ingebruik',
                                  definitie='4G2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4g2.5'),
        '4g25': KeuzelijstWaarde(invulwaarde='4g25',
                                 label='4G25',
                                 status='ingebruik',
                                 definitie='4G25',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4g25'),
        '4g35': KeuzelijstWaarde(invulwaarde='4g35',
                                 label='4G35',
                                 status='ingebruik',
                                 definitie='4G35',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4g35'),
        '4g4': KeuzelijstWaarde(invulwaarde='4g4',
                                label='4G4',
                                status='ingebruik',
                                definitie='4G4',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4g4'),
        '4g6': KeuzelijstWaarde(invulwaarde='4g6',
                                label='4G6',
                                status='ingebruik',
                                definitie='4G6',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4g6'),
        '4x1.5': KeuzelijstWaarde(invulwaarde='4x1.5',
                                  label='4x1.5',
                                  status='ingebruik',
                                  definitie='4x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x1.5'),
        '4x10': KeuzelijstWaarde(invulwaarde='4x10',
                                 label='4x10',
                                 status='ingebruik',
                                 definitie='4x10',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x10'),
        '4x10-16': KeuzelijstWaarde(invulwaarde='4x10-16',
                                    label='4x10+16',
                                    status='ingebruik',
                                    definitie='4x10+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x10-16'),
        '4x150': KeuzelijstWaarde(invulwaarde='4x150',
                                  label='4x150',
                                  status='ingebruik',
                                  definitie='4x150',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x150'),
        '4x16': KeuzelijstWaarde(invulwaarde='4x16',
                                 label='4x16',
                                 status='ingebruik',
                                 definitie='4x16',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x16'),
        '4x16-10': KeuzelijstWaarde(invulwaarde='4x16-10',
                                    label='4x16+10',
                                    status='ingebruik',
                                    definitie='4x16+10',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x16-10'),
        '4x16-16': KeuzelijstWaarde(invulwaarde='4x16-16',
                                    label='4x16+16',
                                    status='ingebruik',
                                    definitie='4x16+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x16-16'),
        '4x2.5': KeuzelijstWaarde(invulwaarde='4x2.5',
                                  label='4x2.5',
                                  status='ingebruik',
                                  definitie='4x2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x2.5'),
        '4x2.5-16': KeuzelijstWaarde(invulwaarde='4x2.5-16',
                                     label='4x2.5+16',
                                     status='ingebruik',
                                     definitie='4x2.5+16',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x2.5-16'),
        '4x2.5-2.5': KeuzelijstWaarde(invulwaarde='4x2.5-2.5',
                                      label='4x2.5+2.5',
                                      status='ingebruik',
                                      definitie='4x2.5+2.5',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x2.5-2.5'),
        '4x25': KeuzelijstWaarde(invulwaarde='4x25',
                                 label='4x25',
                                 status='ingebruik',
                                 definitie='4x25',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x25'),
        '4x25-16': KeuzelijstWaarde(invulwaarde='4x25-16',
                                    label='4x25+16',
                                    status='ingebruik',
                                    definitie='4x25+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x25-16'),
        '4x25-2.5': KeuzelijstWaarde(invulwaarde='4x25-2.5',
                                     label='4x25+2.5',
                                     status='ingebruik',
                                     definitie='4x25+2.5',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x25-2.5'),
        '4x2x0.8': KeuzelijstWaarde(invulwaarde='4x2x0.8',
                                    label='4x2x0.8',
                                    status='ingebruik',
                                    definitie='4x2x0.8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x2x0.8'),
        '4x35': KeuzelijstWaarde(invulwaarde='4x35',
                                 label='4x35',
                                 status='ingebruik',
                                 definitie='4x35',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x35'),
        '4x4': KeuzelijstWaarde(invulwaarde='4x4',
                                label='4x4',
                                status='ingebruik',
                                definitie='4x4',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x4'),
        '4x50': KeuzelijstWaarde(invulwaarde='4x50',
                                 label='4x50',
                                 status='ingebruik',
                                 definitie='4x50',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x50'),
        '4x6': KeuzelijstWaarde(invulwaarde='4x6',
                                label='4x6',
                                status='ingebruik',
                                definitie='4x6',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x6'),
        '4x6-16': KeuzelijstWaarde(invulwaarde='4x6-16',
                                   label='4x6+16',
                                   status='ingebruik',
                                   definitie='4x6+16',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x6-16'),
        '4x70': KeuzelijstWaarde(invulwaarde='4x70',
                                 label='4x70',
                                 status='ingebruik',
                                 definitie='4x70',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/4x70'),
        '5-x-10-mm2': KeuzelijstWaarde(invulwaarde='5-x-10-mm2',
                                       label='5 x 10 mm²',
                                       status='uitgebruik',
                                       definitie='uitgebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5-x-10-mm2'),
        '5-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='5-x-2.5-mm2',
                                        label='5 x 2.5 mm²',
                                        status='uitgebruik',
                                        definitie='uitgebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5-x-2.5-mm2'),
        '5g1.5': KeuzelijstWaarde(invulwaarde='5g1.5',
                                  label='5G1.5',
                                  status='ingebruik',
                                  definitie='5G1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5g1.5'),
        '5g10': KeuzelijstWaarde(invulwaarde='5g10',
                                 label='5G10',
                                 status='ingebruik',
                                 definitie='5G10',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5g10'),
        '5g16': KeuzelijstWaarde(invulwaarde='5g16',
                                 label='5G16',
                                 status='ingebruik',
                                 definitie='5G16',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5g16'),
        '5g2.5': KeuzelijstWaarde(invulwaarde='5g2.5',
                                  label='5G2.5',
                                  status='ingebruik',
                                  definitie='5G2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5g2.5'),
        '5g4': KeuzelijstWaarde(invulwaarde='5g4',
                                label='5G4',
                                status='ingebruik',
                                definitie='5G4',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5g4'),
        '5g6': KeuzelijstWaarde(invulwaarde='5g6',
                                label='5G6',
                                status='ingebruik',
                                definitie='5G6',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5g6'),
        '5x2.5': KeuzelijstWaarde(invulwaarde='5x2.5',
                                  label='5x2.5',
                                  status='ingebruik',
                                  definitie='5x2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5x2.5'),
        '5x4': KeuzelijstWaarde(invulwaarde='5x4',
                                label='5x4',
                                status='ingebruik',
                                definitie='5x4',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5x4'),
        '5x6': KeuzelijstWaarde(invulwaarde='5x6',
                                label='5x6',
                                status='ingebruik',
                                definitie='5x6',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/5x6'),
        '6x25-16': KeuzelijstWaarde(invulwaarde='6x25-16',
                                    label='6x25+16',
                                    status='ingebruik',
                                    definitie='6x25+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/6x25-16'),
        '7g2.5': KeuzelijstWaarde(invulwaarde='7g2.5',
                                  label='7G2.5',
                                  status='ingebruik',
                                  definitie='7G2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/7g2.5'),
        '7x1.5': KeuzelijstWaarde(invulwaarde='7x1.5',
                                  label='7x1.5',
                                  status='ingebruik',
                                  definitie='7x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/7x1.5'),
        'zonder-bijkomende-specificatie': KeuzelijstWaarde(invulwaarde='zonder-bijkomende-specificatie',
                                                           label='zonder bijkomende specificatie',
                                                           status='uitgebruik',
                                                           definitie='uitgebruik',
                                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVoedingskabelAdersEnSectie/zonder-bijkomende-specificatie')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

